% To run LxS_Library_Example.m, the 
% dataReceived_Callback.m file need to be in the same folder.
% The LxS_Lib.dll need to be in the subfolder LxS_Lib
% LxS_Library_Example.m works with LPS devices only.

% This is a simple example to show how to use the LxS_Lib.dll with matlab.
% The example:
% 1. Connects with the sensor.
% 2. Change "Operation Mode" to "Input triggered"
% 3. Triggers 10 times
% 4. Plots profiles in a 2D-graph

%% Check Matlab Version
if verLessThan('matlab', '7.8')
    msgbox({'You need at least Matlab 2009a'; 'to load assemblies into Matlab'}, 'Wrong Matlab Version', 'error')
    return
end

%% Load library and establish connection
SensorIPAddress = '192.168.60.3';
SensorPort = 9008;
PCPort = 5634;

% Create the path to the Library 
DLL_PATH = fullfile(cd,'\LxS_Lib\LxS_Lib.dll');

% Load the LxS Assembly into Matlab
NET.addAssembly(DLL_PATH);

% Create a network endpoint as IP address and port number
ipEndpoint = System.Net.IPEndPoint(System.Net.IPAddress.Parse(SensorIPAddress), SensorPort);

% add the LxS_Library class names to the import list to directly address 
% them without using LxS_Library.
import LxS_Library.*

% Create a LxS_Device object
lxsDevice = LxS_Device(PCPort, ipEndpoint);
lxsDevice.TimeOut = 500;

% Establish an IP connection to the sensor
isConnected = lxsDevice.Connect;
if ~isConnected
    % if the sensor has been connected before or is connected to another 
    % source the sensor sends a NACK. 
    % Disconnect first and then connect again
    lxsDevice.Disconnect;
    isConnected =lxsDevice.Connect;
    % if Connection fails again, Dispose Object and return, check
    % connection with wireshark ....
    if ~isConnected
        lxsDevice.Dispose;
        clear('lxsDevice')
        return
    end
end

% Set the sensor into Command Mode
lxsDevice.SetSensorMode(LxS_Mode.COMMAND);

% Read the actual inspection task number from the sensor
actInspectionTaskNumber = lxsDevice.GetInspectionTask;

% Read the task settings from the sensor 
actInspParameterSetting = lxsDevice.GetTaskSettings(uint16(0));

% Change parameter 3002 = "Operation Mode" to triggered
paramID = 3002;
newValue = 1;
sizeNewValue = size(newValue);
paramValueNetAr = NET.createArray('System.UInt16',sizeNewValue(2));
for iCnt = 1:sizeNewValue(2)
    paramValueNetAr.Set((iCnt-1), uint16(newValue(iCnt)));
end
okFlag = actInspParameterSetting.GetParameterByID(uint16(paramID)).SetField(paramValueNetAr);

% Write changed setting in the sensor temporarily.
lxsDevice.SetTaskSettings(uint16(0), actInspParameterSetting, false);

% register a handler that handles data events from the LxS_Device object
addlistener(lxsDevice, 'DataHandler', @dataReceived_Callback);

% Set the sensor into Measurement Mode
lxsDevice.SetSensorMode(LxS_Mode.MEASURE);

%% Trigger sensor
% Now trigger 10 measurements everey second with the EthernetTrigger
% The event handler plots the received data
for n = 1:10
    lxsDevice.EthernetTrigger();
    pause(1)
end

%% Disconnect and clean up
% Disconnect, free memory and finally clear Matlab workspace
lxsDevice.Disconnect;
lxsDevice.Dispose;
clear

